@@ -24,29 +24,29 @@ T = t.TypeVar('T')
 class RESTOptions:
     """Handler Options."""
 
-    name: str = ''
-    name_id: str = ''
+    name: t.Optional[str] = None
+    name_id: str = 'id'
 
     # limit: Paginate results (set to None for disable pagination)
     limit: int = 0
     limit_max: int = 0
 
     # Base class for filters
+    filters: Filters
     filters_cls: t.Type[Filters] = Filters
 
     # Base class for sorting
+    sorting: Sorting
     sorting_cls: t.Type[Sorting] = Sorting
 
     # Auto generation for schemas
+    Schema: t.Type[ma.Schema]
     schema_base: t.Type[ma.Schema] = ma.Schema
     schema_fields: t.Dict = {}
     schema_meta: t.Dict = {}
     schema_unknown: str = ma.EXCLUDE
 
-    if t.TYPE_CHECKING:
-        filters: Filters
-        sorting: Sorting
-        Schema: t.Type[ma.Schema]
+    base_property: str = 'name'
 
     def __init__(self, cls):
         """Inherit meta options."""
@@ -56,16 +56,11 @@ class RESTOptions:
                     if not k.startswith('_'):
                         setattr(self, k, v)
 
-        self.setup(cls)
+        if getattr(self, self.base_property, None) is not None:
+            self.setup(cls)
 
     def setup(self, cls):
         """Setup the options."""
-        # Setup names
-        cls_name = cls.__name__
-        self.name = self.name or cls_name.lower().split('handler', 1)[0] or cls_name.lower()
-        self.name_id = self.name_id or self.name
-
-        # Setup schema
         if not self.Schema:
             self.Schema = type(
                 self.name.title() + 'Schema', (self.schema_base,),
@@ -80,7 +75,7 @@ class RESTOptions:
 
     def __repr__(self):
         """Represent self as a string."""
-        return "<Options %s>" % self.name
+        return f"<Options {self.name}>"
 
 
 class RESTHandlerMeta(HandlerMeta):
@@ -88,11 +83,10 @@ class RESTHandlerMeta(HandlerMeta):
 
     def __new__(mcs, name, bases, params):
         """Prepare options for the handler."""
-        params.setdefault('Meta', type("Meta", (object,), {}))  # Every handler has uniq meta
         cls = super().__new__(mcs, name, bases, params)
+        cls.meta = cls.meta_class(cls)
 
-        if not getattr(cls.Meta, 'abc', False):
-            cls.meta = cls.meta_class(cls)
+        if getattr(cls.meta, cls.meta_class.base_property, None) is not None:
             cls.meta.filters = cls.meta.filters_cls(cls, cls.meta.filters)
             cls.meta.sorting = cls.meta.sorting_cls(cls, cls.meta.sorting)
 
@@ -115,8 +109,6 @@ class RESTBase(Handler, metaclass=RESTHandlerMeta):
     class Meta:
         """Tune the handler."""
 
-        abc: bool = True  # The class is abstract, meta wouldn't be generated
-
         # Resource filters
         filters: t.Sequence[t.Union[str, t.Tuple[str, str], Filter]] = ()
 
@@ -154,7 +146,6 @@ class RESTBase(Handler, metaclass=RESTHandlerMeta):
             return await method(request, resource=resource)
 
         meta = self.meta
-        query = request.url.query
 
         # Filter collection
         if meta.filters:
@@ -167,17 +158,11 @@ class RESTBase(Handler, metaclass=RESTHandlerMeta):
         # Paginate the collection
         headers = {}
         if meta.limit:
-            limit = query.get(LIMIT_PARAM) or meta.limit
-            try:
-                limit = min(abs(int(limit)), meta.limit_max)
-                offset = int(query.get(OFFSET_PARAM, 0))
-                if limit and offset >= 0:
-                    self.collection, total = await self.paginate(
-                        request, limit=limit, offset=offset)
-                    headers = self.paginate_prepare_headers(limit, offset, total)
-
-            except ValueError:
-                raise APIError.BAD_REQUEST('Pagination params are invalid')
+            limit, offset = self.paginate_prepare_params(request)
+            if limit and offset >= 0:
+                self.collection, total = await self.paginate(
+                    request, limit=limit, offset=offset)
+                headers = self.paginate_prepare_headers(limit, offset, total)
 
         response = await method(request, resource=resource)
         if headers:
@@ -193,17 +178,48 @@ class RESTBase(Handler, metaclass=RESTHandlerMeta):
             raise Exception('The handler is not routed by any API')  # TODO
         return self._api
 
+    async def authorize(self, request: Request):
+        """Default authorization method. Proxy auth to self.api."""
+        auth = await self.api.authorize(request)
+        if not auth:
+            raise APIError.UNAUTHORIZED()
+        return auth
+
+    # Prepare data
+    # ------------
     @abc.abstractmethod
     async def prepare_collection(self, request: Request) -> t.Any:
         """Prepare a collection of resources. Create queryset, db cursor and etc."""
         raise NotImplementedError
 
+    async def prepare_resource(self, request: Request) -> t.Any:
+        """Load a resource."""
+        return request['path_params'].get(self.meta.name_id)
+
+    # Paginate
+    # --------
+    def paginate_prepare_headers(self, limit, offset, total):
+        """Prepare pagination headers."""
+        return {'x-total': total, 'x-limit': limit, 'x-offset': offset}
+
+    def paginate_prepare_params(self, request: Request) -> t.Tuple[int, int]:
+        """Prepare pagination params."""
+        meta = self.meta
+        query = request.url.query
+        limit = query.get(LIMIT_PARAM) or meta.limit
+        try:
+            return min(abs(int(limit)), meta.limit_max), int(query.get(OFFSET_PARAM, 0))
+        except ValueError:
+            raise APIError.BAD_REQUEST('Pagination params are invalid')
+
     @abc.abstractmethod
     async def paginate(self, request: Request, *, limit: int = 0,
                        offset: int = 0) -> t.Tuple[t.Any, int]:
         """Paginate the results."""
         raise NotImplementedError
 
+    # Manage data
+    # -----------
     @abc.abstractmethod
     async def save(self, request: Request, *, resource: T = None) -> T:
         """Save the given resource."""
@@ -214,27 +230,15 @@ class RESTBase(Handler, metaclass=RESTHandlerMeta):
         """Remove the given resource."""
         raise NotImplementedError
 
-    async def prepare_resource(self, request: Request) -> t.Any:
-        """Load a resource."""
-        return request['path_params'].get(self.meta.name_id)
-
-    def paginate_prepare_headers(self, limit, offset, total):
-        """Prepare pagination headers."""
-        return {'x-total': total, 'x-limit': limit, 'x-offset': offset}
-
-    async def authorize(self, request: Request):
-        """Default authorization method. Proxy auth to self.api."""
-        auth = await self.api.authorize(request)
-        if not auth:
-            raise APIError.UNAUTHORIZED()
-        return auth
-
+    # Parse data
+    # -----------
     async def get_schema(self, request: Request, resource=None) -> ma.Schema:
         """Initialize marshmallow schema for serialization/deserialization."""
         assert self.meta.Schema, 'RESTHandler.meta.Schema is required.'
+        query = request.url.query
         return self.meta.Schema(
-            only=request.url.query.get('schema_only'),
-            exclude=request.url.query.get('schema_exclude', ()),
+            only=query.get('schema_only'),
+            exclude=query.get('schema_exclude', ()),
         )
 
     async def parse(self, request: Request):
@@ -303,10 +307,7 @@ class RESTBase(Handler, metaclass=RESTHandlerMeta):
 class RESTHandler(RESTBase, openapi.OpenAPIMixin):
     """Basic Handler Class."""
 
-    class Meta:
-        """Tune the handler."""
-
-        abc: bool = True                        # The class is abstract, meta wouldn't be generated
+    pass
 
 
 def to_sort(sort_params: t.Sequence[str]) -> t.Generator[t.Tuple[str, bool], None, None]:
